@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+from __future__ import division, absolute_import
 from RO.Astro import llv
 
 __all__ = ["mjdFromEpJ"]
@@ -14,6 +14,7 @@ def mjdFromEpJ (epj):
     - mjd   Modified Julian Date (JD - 2400000.5).
     
     History:
-    2002-08-06 R Owen Just a more memorable name for llv.epj2d.
+    2002-08-06 ROwen    Just a more memorable name for llv.epj2d.
+    2014-04-25 ROwen    Add from __future__ import division, absolute_import.
     """
     return llv.epj2d(epj)
