@@ -35,21 +35,21 @@ with file(os.path.join("docs", "VersionHistory.html")) as vhist:
                 print "Error: version in VersionHistory.html = %s != %s" % (histVersStr, Version.__version__)
                 sys.exit(0)
 
-print "Status of subversion repository:"
+print "Status of git repository:"
 
-subprocess.call(["svn", "status"])
+subprocess.call(["git", "status"])
 
-versOK = raw_input("Is the subversion repository up to date? (y/[n]) ")
+versOK = raw_input("Is the git repository up to date? (y/[n]) ")
 if not versOK.lower() == "y":
     sys.exit(0)
 
-print "Subversion repository OK"
+print "git repository OK"
 
-# warning: do not build from export because the svn info is required to get the data files included
-print "Building test build"
+# warning: do not build from export because the git info is required to get the data files included
+print "Building the distribution package"
 status = subprocess.call(["python", "setup.py", "sdist"])
 if status != 0:
-    print "Test build failed!"
+    print "Build failed!"
 
 # make sure the bitmap files got into the distribution
 # (sometimes they fail to, and it's a silent error unless I check)
@@ -64,14 +64,11 @@ except Exception:
     print "Error: distribution is missing its bitmap files!"
     sys.exit(1)
 
-
-print "Deleting test build %r" % (distDir,)
-shutil.rmtree(distDir)
-
-print "Building final build and uploading"
-status = subprocess.call(["python", "setup.py", "sdist", "upload", "--show-response"])
+print "Uploading to PyPI"
+status = subprocess.call(["twine", "upload", "dist/%s.tar.gz" % (distBaseName,)])
 if status != 0:
-    print "Build and upload failed!"
+    print "Upload failed!"
+    sys.exit(1)
 
 eggDir = os.path.abspath("RO.egg-info")
 
